%global major_version 17
%define dlname Botan
%define botan_ver 2

%define with_checks 0

%define libname %mklibname botan2_ %{major_version}
%define devname %mklibname botan2 -d

Name:           botan2
Version:        2.17.3
%define         subrel 2
Release:        %mkrel 2
Summary:        Crypto and TLS for C++11
Group:          System/Libraries
License:        BSD
URL:            https://botan.randombit.net/
Source0:        https://botan.randombit.net/releases/%{dlname}-%{version}.tar.xz#!/%{name}-%{version}.tar.xz

#
# Security Patches
# P100 -> ...
#
# CVE-2021-40529
Patch100:	9a23e4e3bc3966340531f2ff608fa9d33b5185a2.patch 
# Patch from SUSE
Patch101:	Botan-CVE-2022-43705.patch

BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  python3dist(docutils)
BuildRequires:  python3dist(sphinx)
BuildRequires:  graphviz
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  boost-devel

Requires:       python3

%description
Botan is a BSD-licensed crypto library written in C++. It provides a
wide variety of basic cryptographic algorithms, X.509 certificates and
CRLs, PKCS \#10 certificate requests, a filter/pipe message processing
system, and a wide variety of other features, all written in portable
C++. The API reference, tutorial, and examples may help impart the
flavor of the library. This is the current stable release branch 2.x
of Botan.

%package        -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 2.6.0-6

%description    -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%package        -n %{libname}
Summary:        Library files for %{name}
Group:          System/Libraries
Requires:       %{name} >= %{version}-%{release}
Conflicts:      %{name} < 2.6.0-6

%description    -n %{libname}
The %{libname} package contains library files for %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
Documentation for %{name}.

This package contains HTML documentation for %{name}.


%package -n python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package contains the Python3 binding for %{name}.


%prep
%autosetup -p1 -n %{dlname}-%{version}

pathfix.py -pni "%{__python3}" \
configure.py \
src/scripts/build_docs.py \
src/scripts/check.py \
src/scripts/ci_build.py \
src/scripts/cleanup.py \
src/scripts/dist.py \
src/scripts/gen_os_features.py \
src/scripts/install.py \
src/scripts/python_unittests.py \
src/scripts/python_unittests_unix.py \
src/scripts/show_dependencies.py \
src/scripts/test_cli_crypt.py \
src/scripts/test_python.py \
src/scripts/tls_suite_info.py \
src/python/botan2.py

%build
# we have the necessary prerequisites, so enable optional modules
%global enable_modules bzip2,zlib,openssl,boost,sqlite3,lzma

./configure.py \
        --prefix=%{_prefix} \
        --libdir=%{_lib} \
        --docdir=%{_docdir} \
        --cc=gcc \
        --os=linux \
        --cpu=%{_arch} \
        --enable-modules=%{enable_modules} \
        --with-python-version=%{python3_version} \
	--with-sphinx \
        --disable-static-library \
        --with-debug-info

%make_build

%install
%make_install \
     INSTALL_CMD_EXEC="install -p -m 755" \
     INSTALL_CMD_DATA="install -p -m 644"

chmod 755 %{buildroot}%{python3_sitearch}/botan2.py

find %{buildroot} -name '*.a' -delete

%if %with_checks
%check
%ifnarch %{arm}
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ./botan-test
%endif
%endif

%files
%license license.txt
%{_bindir}/botan
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libbotan-%{botan_ver}.so.%{major_version}{,.*}

%files -n %{devname}
%license license.txt
%{_includedir}/botan-%{botan_ver}/
%{_libdir}/libbotan-%{botan_ver}.so
%{_libdir}/pkgconfig/botan-%{botan_ver}.pc

%files doc
%license license.txt
%{_docdir}/botan-%{version}/

%files -n python3-%{name}
%license license.txt
%{python3_sitearch}/%{name}.py
%{python3_sitearch}/__pycache__/*


%changelog
* Wed Nov 23 2022 kekepower <kekepower> 2.17.3-2.2.mga8
+ Revision: 1910616
- Add patch from SuSE to fix CVE-2022-43705 (mga#31176)
+ neoclust <neoclust>
- Add P100: Fixes CVE-2021-40529 (mga#29659)

* Thu Dec 31 2020 wally <wally> 2.17.3-2.mga8
+ Revision: 1666739
- rebuild for boost 1.75.0

* Tue Dec 22 2020 kekepower <kekepower> 2.17.3-1.mga8
+ Revision: 1662697
- Update to version 2.17.3

* Sun Dec 20 2020 wally <wally> 2.17.2-2.mga8
+ Revision: 1661981
- rebuild for boost 1.74.0

* Sat Nov 14 2020 kekepower <kekepower> 2.17.2-1.mga8
+ Revision: 1645616
- Update to version 2.17.2

* Sun Nov 08 2020 kekepower <kekepower> 2.17.1-1.mga8
+ Revision: 1643665
- Update to version 2.17.1

* Thu Nov 05 2020 kekepower <kekepower> 2.17.0-1.mga8
+ Revision: 1642949
- Update to version 2.17.0

* Thu Oct 22 2020 daviddavid <daviddavid> 2.16.0-1.mga8
+ Revision: 1638525
- new version: 2.16.0
- now libmajor is 16

* Fri Jul 17 2020 daviddavid <daviddavid> 2.15.0-1.mga8
+ Revision: 1606718
- new version: 2.15.0
- now libmajor is 15

* Sun May 03 2020 wally <wally> 2.14.0-2.mga8
+ Revision: 1578035
- rebuild for boost 1.73.0

* Tue Apr 07 2020 kekepower <kekepower> 2.14.0-1.mga8
+ Revision: 1565474
- Update to version 2.14.0
- Enable extra modules - boost,sqlite3,lzma

* Wed Feb 19 2020 umeabot <umeabot> 2.13.0-3.mga8
+ Revision: 1542957
- Mageia 8 Mass Rebuild

* Wed Jan 08 2020 daviddavid <daviddavid> 2.13.0-2.mga8
+ Revision: 1477272
- disable testsuite on arm

* Wed Jan 08 2020 daviddavid <daviddavid> 2.13.0-1.mga8
+ Revision: 1477262
- new version: 2.13.0
- now libmajor is 13

* Thu Dec 05 2019 daviddavid <daviddavid> 2.12.1-1.mga8
+ Revision: 1464532
- new version: 2.12.1
- now libmajor is 12

* Fri Sep 20 2019 daviddavid <daviddavid> 2.11.0-3.mga8
+ Revision: 1444031
- rebuild for python3.8

* Sat Aug 17 2019 wally <wally> 2.11.0-2.mga8
+ Revision: 1429491
- drop python2-sphinx BR

* Mon Jul 15 2019 daviddavid <daviddavid> 2.11.0-1.mga8
+ Revision: 1421532
- new version: 2.11.0
- now libmajor is 11

* Thu Jul 04 2019 wally <wally> 2.10.0-2.mga8
+ Revision: 1418497
- loosen lib requires

* Sun Jun 30 2019 daviddavid <daviddavid> 2.10.0-1.mga8
+ Revision: 1416326
- new version: 2.10.0
- now libmajor is 10

* Mon Jan 07 2019 kekepower <kekepower> 2.9.0-2.mga7
+ Revision: 1351021
- Rebuild for Python 3.7

* Sat Jan 05 2019 kekepower <kekepower> 2.9.0-1.mga7
+ Revision: 1349281
- Update to version 2.9.0

* Sun Oct 28 2018 daviddavid <daviddavid> 2.8.0-2.mga7
+ Revision: 1326405
- add some missing Group
- fix some description and summary
- fix some Conflicts, Obsoletes, Provides
+ kekepower <kekepower>
- Requires appropriate sub packages

* Sun Oct 28 2018 kekepower <kekepower> 2.8.0-1.mga7
+ Revision: 1326389
- Update to version 2.8.0
- Create proper sub pacakges for dev and libs

* Fri Sep 21 2018 umeabot <umeabot> 2.6.0-5.mga7
+ Revision: 1295632
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 wally <wally> 2.6.0-4.mga7
+ Revision: 1248827
- add back pycache

* Fri Jul 06 2018 daviddavid <daviddavid> 2.6.0-3.mga7
+ Revision: 1242164
- update files list (no more __pycache__ reference)

* Fri May 25 2018 shlomif <shlomif> 2.6.0-2.mga7
+ Revision: 1232167
- fix owned dirs as reported by youri
- New version 2.6.0
+ kekepower <kekepower>
- imported package botan2

